kedro.extras.datasets.pandas.GBQQueryDataSet — Kedro 0.17.6 documentation

# kedro.extras.datasets.pandas.GBQQueryDataSet

class `kedro.extras.datasets.pandas.` `GBQQueryDataSet`(sql=None, project=None, credentials=None, load_args=None, fs_args=None, filepath=None)

  `GBQQueryDataSet` loads data from a provided SQL query from Google BigQuery. It uses `pandas.read_gbq` which itself uses `pandas-gbq` internally to read from BigQuery table. Therefore it supports all allowed pandas options on `read_gbq`.

  Example adding a catalog entry with YAML API:

      vehicles:
        type: pandas.GBQQueryDataSet
        sql: "select shuttle, shuttle_id from spaceflights.shuttles;"
        project: my-project
        credentials: gbq-creds
        load_args:
          reauth: True

  Example using Python API:

      from kedro.extras.datasets.pandas import GBQQueryDataSet

      sql = "SELECT * FROM dataset_1.table_a"

      data_set = GBQQueryDataSet(sql, project='my-project')

      sql_data = data_set.load()

  Attributes

  `DEFAULT_LOAD_ARGS` |

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `save`(data) | Saves data by delegation to the provided save method.

  `DEFAULT_LOAD_ARGS`: Dict[str, Any] = {}
  `__init__`(sql=None, project=None, credentials=None, load_args=None, fs_args=None, filepath=None)

    Creates a new instance of `GBQQueryDataSet`.

    Parameters

      - sql (`Optional`[`str`]) – The sql query statement.

      - project (`Optional`[`str`]) – Google BigQuery Account project ID. Optional when available from the environment. https://cloud.google.com/resource-manager/docs/creating-managing-projects

      - credentials (`Union`[`Dict`[`str`, `Any`], `Credentials`, `None`]) – Credentials for accessing Google APIs. Either `google.auth.credentials.Credentials` object or dictionary with parameters required to instantiate `google.oauth2.credentials.Credentials`. Here you can find all the arguments: https://google-auth.readthedocs.io/en/latest/reference/google.oauth2.credentials.html

      - load_args (`Optional`[`Dict`[`str`, `Any`]]) – Pandas options for loading BigQuery table into DataFrame. Here you can find all available arguments: https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.read_gbq.html All defaults are preserved.

      - fs_args (`Optional`[`Dict`[`str`, `Any`]]) – Extra arguments to pass into underlying filesystem class constructor (e.g. {“project”: “my-project”} for `GCSFileSystem`) used for reading the SQL query from filepath.

      - filepath (`Optional`[`str`]) – A path to a file with a sql query statement.

    Raises

      DataSetError – When `sql` and `filepath` parameters are either both empty or both provided, as well as when the save() method is invoked.

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`